@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "macher" "0.5.2"
+(define-package "macher" "20260107.2043"
   "LLM implementation toolset."
   '((emacs "30.1")
     (gptel "0.9.9.3"))
